#
# spec file for package lf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lf
Version:        31
Release:        bp156.1.5
Summary:        Terminal file manager (with sixel support)
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/gokcehan/lf
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging

%description
lf (as in "list files") is a terminal file manager written in Go with a
heavy inspiration from ranger file manager

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a 1

%build
go build -v -buildmode=pie -ldflags="-s -w \
 -X main.gVersion=%{version}" \
 -mod vendor -trimpath .

%install
install -Dm755 -t "%{buildroot}%{_bindir}" lf
install -Dm644 -t "%{buildroot}%{_mandir}/man1" lf.1
install -Dm644 -t "%{buildroot}%{_docdir}/%{name}" README.md etc/lfrc.example
install -Dm644 -t "%{buildroot}%{_datadir}/applications" lf.desktop
install -Dm644 -t "%{buildroot}%{_datadir}/bash-completion/completions/lf" etc/lf.bash
install -Dm644 -t "%{buildroot}%{_datadir}/fish/vendor_functions.d" etc/lfcd.fish
install -Dm644 -t "%{buildroot}%{_datadir}/fish/vendor_completions.d/lf.fish" etc/lf.fish
install -Dm644 -t "%{buildroot}%{_datadir}/zsh/site-functions/_lf" etc/lf.zsh
install -Dm644 -t "%{buildroot}%{_licensedir}/lf" LICENSE

%files
%doc README.md lfrc.example
%license LICENSE

%{_mandir}/man1/lf.1*
%{_bindir}/lf
%{_datadir}/applications/%{name}.desktop

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Sun Sep 17 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 31:
  Breaking:
  * There has been some changes in the server protocol. Make sure
    to kill the old server process when you update to avoid errors
    (i.e. lf -remote 'quit!').
  * A new server command query is added to expose internal state
    to users (#1384) (by @joelim-work).
  * A new builtin command cmds is added to display the commands.
    The old builtin command jumps is now removed. The builtin
    commands maps and cmaps now use the new server command.
  * Cleaning program should now instead receive an additional
    sixth argument for the next file path to be previewed to allow
    comparisons with the previous file path. User options (i.e.
    user_{option}) are now exported whenever they are changed
    (#1418) (by @raslop).
  * Command outputs are now exclusively attached to stderr to allow
    printing the last directory or selection to stdout (#1399 and
    [#1402]) (by @joelim-work). Two new command line options -print-
    last-dir and -print-selection are added to print the last
    directory and selection to stdout. The example script etc/
    lfcd.sh is updated to use -print-last-dir instead. Other lfcd
    scripts are also likely to be updated in the future to use the
    new method (patches are welcome).
  * The option ruler is now deprecated in favor of its replacement
    rulerfmt (#1386) (by @joelim-work). The new rulerfmt option is
    more capable (i.e. displays option values, supports colors and
    attributes, and supports optional fields) and more consistent
    with the rest of our options. See the documentation for more
    information.
  New:
  * Modifier keys (i.e. control, shift, alt) with special keys
    (e.g. arrows, enter) are now supported for most combinations
    (#1248) (by @joelim-work).
  * A new option borderfmt is added to configure colors for pane
    borders (#1251) (by @joelim-work).
  * New lf specific environment variables, LF_CONFIG_HOME on
    Windows and LF_CONFIG/DATA_HOME on Unix, are now supported to
    set the configuration directory (#1253) (by @alok-mishra).
  * Tilde (i.e. ~) expansion is performed during completion to be
    able to use expanded tilde paths as command arguments (#1246)
    (by @joelim-work).
  * A new option preserve is added to preserve attributes (i.e.
    mode and timestamps) while copying (#1026) (by @raslop).
  * The file etc/icons.example is updated for nerd-fonts v3.0.0
    (#1271) (by @MunifTanjim).
  * A new builtin command clearmaps is added to clear all default
    keybindings except for read (i.e. :) and cmap keybindings to be
    able to :quit (#1286) (by @joelim-work).
  * A new option statfmt is added to configure the status line at
    the bottom (#1288) (by @joelim-work).
  * A new option truncatepct is added to determine the location of
    truncation from the beginning in terms of percentage (#1029)
    (by @raslop).
  * A new option dupfilefmt is added to configure the names of
    duplicate files while copying (#1315) (by @Limero).
  * Shell scripts etc/lf.nu and etc/lfcd.nu are added to the
    repository to allow completion and directory change with
    Nushell (#1341) (by @mauerlaeufer).
  * A new configuration keyword setlocal is added to configure
    directory specific options (#1381) (by @gokcehan).
  * A new command line command cmd-delete-word-back (default a-
    backspace and a-backspace2) is added to use word boundaries
    when deleting a word backwards (#1409) (by @janpeterd).
  Fix:
  * Cursor positions in the directory should now be preserved after
    file operations that changes the directory (e.g. create or
    delete) (#1247) (by @joelim-work).
  * Option reverse should now respect to sort stability
    requirements (#1261) (by @joelim-work).
  * Backspace should not exit filter mode anymore (#1269) (by
    @jdujava).
  * Truncated double width characters should not cause misalignment
    for the file information (#1272) (by @joelim-work).
  * Piping shell commands should not refresh the preview anymore
    (#1281) (by @joelim-work).
  * Cursor position should now update properly after a terminal
    resize (#1290) (by @joelim-work).
  * Directories should now be reloaded properly after a delete
    operation (#1292) (by @joelim-work).
  * Executable file completion should not add entries to the log
    file anymore (#1307) (by @joelim-work).
  * Blank input lines are now allowed in piping shell commands
    (#1308) (by @joelim-work).
  * Shell commands arguments on Windows should now be quoted
    properly to fix various issues (#1309) (by @joelim-work).
  * Reloading in a symlink directory should not follow the symlink
    anymore (#1327) (by @joelim-work).
  * Command load should not flicker image previews anymore (#1335)
    (by @joelim-work).
  * Filenames should only be quoted for cmd on Windows to avoid
    quoting issues for powershell (#1371) (by @joelim-work).
  * Inaccessible files should now be included in the directory list
    and display their lstat errors in the status line at the bottom
    (#1382) (by @jantatje).
  * Command line command cmd-delete-word should now add the deleted
    text to the yank buffer (#1409) (by @janpeterd).
* Sun Aug 13 2023 Joshua Smith <jsmithfpv@gmail.com>
- Switch upstream repo as upstream is shipping sixel now
- Specfile cleanup
- Update to version 30+dd82949:
  * Sixel preview (#1211)
  * Fix cursor location when printing statline (#1348)
  * Remove environment exports from preview thread (#1354)
  * Clean image preview on `set preview!` (#1350)
  * Support optional fields for `statfmt` option (#1337)
  * Call `load` after shell-async commands (#1345)
* Mon May 29 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 30:
  * preserve mtime when copying files (#1026)
  * Bound cursor position when selecting file (#1247)
  * Expand tilde during autocompletion (#1246)
  * Refactor pager commands & synchronous shell commands (#1243)
  * LF_CONFIG_HOME environment variable  (#1253)
  * Support custom colors for `drawbox` characters (#1251)
  * Support modifiers in special key mappings (#1248)
  * Fix count when parsing `bottom` command (#1240)
  * Add `jumps` command for displaying the jump list (#1233)
  * Separate filter from selections in the ui ruler (#1223)
  * Prevent scrolling to bottom when selecting files (#1222)
* Fri May 12 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 29:
  * allow previews of up to 5MB per line
  * Validate `selmode` setting (#1206)
  * Fix statusbar spacing (#1205)
  * add 'ruler' to completion
  * Customizable statusline, df (#1168)
  * Fix crash when sorting files in a directory (#1204)
  * Simplify edge calculation when scrolling down (#1194)
  * Use $VISUAL for the `e` command instead of $EDITOR (#1197)
  * Make `:maps` work on Windows and add `:cmaps`. (#1201)
  * Add support for moving to a specific line (#1196)
  * lfrc.example: Add mkdir, add "show execution result" (#1188)
  * add file operations to non-features in readme
  * Make the `:doc` command work even if `lf` is not in the PATH,
    add `lf` environment variable (#1176)
  * Export count as a variable when running commands (#1187)
  * Completion: always insert longest match (#1184)
  * Fix infinite loop in listMatches (#1183)
  * Support custom line number colors (#1177)
  * Display zero when relativenumber is enabled (#1171)
  * Use tcell constants for drawbox (#1170)
  * Improve preview loading message flickering (#1154)
  * Enhance rename prompt (#1162)
  * Avoid refreshing previews for async shell commands (#1164)
  * add errors for unexpected boolean option values
  * add 'true/false' syntax for boolean options
  * Fix width used for line numbers (#1151)
  * Refactor code for printing directories (#1150)
  * Update file info after reload command (#1149)
  * Delete stale dircache entry during rename (#1138)
  * `invert-below` command to substitute for visual mode (#1101)
  * Navigate cmd history with up/down (#1112)
  * Option to change look of cursors in parent dirs, rename an
    option. (#1106)
  * Fix documentation for dironly/dirpreviews options (#1105)
  * Allow separate styles for cursor in normal and preview
    panes, simplify `tagfmt` and `errorfmt` (#1086)
  * Refresh preview even if selection doesn't change (#1074)
  * Add example to hiddenfiles documentation (#1073)
  * Disallow exiting from `rename:` mode with backspace (#1060)
  * Bind Ctrl+MouseWheel to scroll up/down (#1051)
  * Make `lfcd` examples safer for people who alias `lf` to
    `lfcd` (#1049)
* Tue Mar  7 2023 Joshua Smith <jsmithfpv@disroot.org>
- Update to version 28.1:
  * revert dim colors for previews
  * add the current example open command to the doc
  * Avoids flicker during open (#991)
  * export lf_width and lf_height as env variables
  * load file info after init (#994)
  * Sixel patch (#1)
* Tue Mar  7 2023 Joshua Smith <jsmithfpv@disroot.org>
- Initial commit for lf 28.1 for openSUSE
